@@ -344,6 +344,8 @@ class DeviceServerBase(object):
             The request message to process.
         """
         send_reply = True
+        # TODO Should check presence of Message-ids against protocol flags and
+        # raise an error as needed.
         if msg.name in self._request_handlers:
             req_conn = ClientRequestConnection(connection, msg)
             try:
@@ -514,7 +516,7 @@ class DeviceServerBase(object):
         if isinstance(connection, ClientRequestConnection):
             self._logger.warn(
                 'Deprecation warning: do not use self.inform() '
-                'within a reply handler context -- use conn.reply()\n'
+                'within a reply handler context -- use req.reply()\n'
                 'Traceback:\n %s', "".join(traceback.format_stack() ))
             # Get the underlying ClientConnectionTCP instance
             connection = connection.client_connection
@@ -573,8 +575,8 @@ class DeviceServerBase(object):
         if isinstance(connection, ClientRequestConnection):
             self._logger.warn(
                 'Deprecation warning: do not use self.reply() '
-                'within a reply handler context -- use conn.reply(*msg_args)\n'
-                'or conn.reply_with_message(msg) Traceback:\n %s',
+                'within a reply handler context -- use req.reply(*msg_args)\n'
+                'or req.reply_with_message(msg) Traceback:\n %s',
                 "".join(traceback.format_stack() ))
             # Get the underlying ClientConnectionTCP instance
             connection = connection.client_connection
@@ -595,6 +597,8 @@ class DeviceServerBase(object):
             reply is sent.
         """
         assert (reply.mtype == Message.REPLY)
+        # TODO The Message-id copying should be handled by the
+        # ClientConnClientConnectionTCP class
         reply.mid = orig_req.mid
         self._send_message(sock, reply)
 
@@ -616,7 +620,7 @@ class DeviceServerBase(object):
             self._logger.warn(
                 'Deprecation warning: do not use self.reply_inform() '
                 'within a reply handler context -- '
-                'use conn.inform(*inform_arguments)\n'
+                'use req.inform(*inform_arguments)\n'
                 'Traceback:\n %s', "".join(traceback.format_stack() ))
             # Get the underlying ClientConnectionTCP instance
             connection = connection.client_connection
@@ -637,6 +641,8 @@ class DeviceServerBase(object):
             inform is sent.
         """
         assert (inform.mtype == Message.INFORM)
+        # TODO The Message-id copying should be handled by the
+        # ClientConnClientConnectionTCP class
         inform.mid = orig_req.mid
         self._send_message(sock, inform)
 
@@ -1526,17 +1532,25 @@ class DeviceServer(DeviceServerBase):
         name : str
             Name of the sensor whose sampling strategy to query or configure.
         strategy : {'none', 'auto', 'event', 'differential', \
-                    'period'}, optional
+                    'period', 'event-rate'}, optional
             Type of strategy to use to report the sensor value. The
             differential strategy type may only be used with integer or float
-            sensors.
+            sensors. If this parameter is supplied, it sets the new strategy.
         params : list of str, optional
             Additional strategy parameters (dependent on the strategy type).
             For the differential strategy, the parameter is an integer or float
             giving the amount by which the sensor value may change before an
-            updated value is sent. For the period strategy, the parameter is
-            the period to sample at in milliseconds. For the event strategy, an
-            optional minimum time between updates in milliseconds may be given.
+            updated value is sent.
+            For the period strategy, the parameter is the sampling period
+            in float seconds.
+            The event strategy has no parameters. Note that this has changed
+            from KATCPv4,
+            For the event-rate strategy, a minimum period between updates and
+            a maximum period between updates (both in float seconds) must be
+            given. If the event occurs more than once within the minimum period,
+            only one update will occur. Whether or not the event occurs, the
+            sensor value will be updated at least once per maximum period.
+            The differential-rate strategy is not supported in this release.
 
         Returns
         -------
@@ -1594,10 +1608,9 @@ class DeviceServer(DeviceServerBase):
                 client.inform(cb_msg)
 
             if katcp_version < SEC_TS_KATCP_MAJOR and strategy == 'period':
-                # Slightly nasty hack, but since period is the only strategy
-                # involves timestamps for v4 is period it's not _too_ nasty :)
-                params = [float(params[0])* MS_TO_SEC_FAC] + params[1:]
-
+                # Slightly nasty hack, but since period is the only v4 strategy
+                # involving timestamps it's not _too_ nasty :)
+                params = [float(params[0]) * MS_TO_SEC_FAC] + params[1:]
             new_strategy = SampleStrategy.get_strategy(
                 strategy, inform_callback, sensor, *params)
 
@@ -1622,9 +1635,9 @@ class DeviceServer(DeviceServerBase):
                 "none", lambda msg: None, sensor)
 
         strategy, params = current_strategy.get_sampling_formatted()
-        if katcp_version <= 4 and strategy == 'period':
-            # Another slightly nasty hack, but since period is the only strategy
-            # involves timestamps for v4 is period it's not _too_ nasty :)
+        if katcp_version < SEC_TS_KATCP_MAJOR and strategy == 'period':
+            # Another slightly nasty hack, but since period is the only
+            # v4 strategy involving timestamps it's not _too_ nasty :)
             params = [int(float(params[0])* SEC_TO_MS_FAC)] + params[1:]
         return req.make_reply("ok", name, strategy, *params)
 
